## letnum

letnum, a simple python library that is able to generate random letter and number combinations for you

it is easy to use and only requires a 1 to 3 lines
## Installation

pip install letnum

```py
#How to Use
from letnum import number, letter, letter_number

#u only need the function name
number()
#by typing the fuction name and running it will ask the amount of letters.
"Enter Any Amount u want.."

"(the same for every function {look at the photo})
```

## Screenshots

![App Screenshot](https://cdn.discordapp.com/attachments/1076890796399276042/1076987830431137852/image.png)

![App Screenshot](https://cdn.discordapp.com/attachments/1076890796399276042/1076987956256059432/image.png)

